"""
*******************************************************************************    
*   BTChip Bitcoin Hardware Wallet Python API 
*   (c) 2014 BTChip - 1BTChip7VfTnrPra5jqci7ejnMguuHogTn
*   
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*   Unless required by applicable law or agreed to in writing, software
*   distributed under the License is distributed on an "AS IS" BASIS,
*   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*   limitations under the License.
********************************************************************************
"""




from setuptools import setup, find_packages
from os.path import dirname, join

# Forked directly from https://github.com/LedgerHQ/btchip-python

here = dirname(__file__)
setup(
    name='gewel-btchip-python',
    version='0.1.2',
    author='gewel',
    author_email='mb@gewel.io',
    description='Python library to communicate with Ledger Nano dongle (Gewel fork)',
    long_description=open(join(here, 'README.md')).read(),
    long_description_content_type='text/markdown',
    url='https://github.com/gewelio/gewel-btchip-python',
    packages=find_packages(),
    install_requires=[
        'hidapi>=0.7.99'
    ],
    extras_require = {
	    'smartcard': [
            'python-pyscard>=1.6.12-4build1',
            'ecdsa>=0.9'
        ]
    },
    include_package_data=True,
    zip_safe=False,
    classifiers=[
	    'License :: OSI Approved :: Apache Software License',
        'Operating System :: POSIX :: Linux',
        'Operating System :: Microsoft :: Windows',
	    'Operating System :: MacOS :: MacOS X'
    ]
)
